# -*- coding: utf-8 -*-
from lxml import etree
import re
from datetime import datetime
from datetime import timedelta
from urlparse import urljoin
from importlib import import_module
SemanticsMatcher = import_module('wasgehtengine.import.semanticsmatcher').SemanticsMatcher
from lxml.html import html5parser

def parse_hidden_elements(node):
    hidden_elem_seq = node.xpath('//h:code/comment()', namespaces={'h': 'http://www.w3.org/1999/xhtml'})
    
    if len(hidden_elem_seq) == 0:
        return None
    
    hidden_elems_string = '<body>'
    
    for hidden_elem_comment in hidden_elem_seq:  
        hidden_elems_string += etree.tostring(hidden_elem_comment)[5:-4]
        
    
    hidden_elems_string += '</body>'

    parsed_hidden_elems = html5parser.fromstring(hidden_elems_string)
    
    return parsed_hidden_elems 

class FacebookEventlinksParser(SemanticsMatcher):
        
    def event_node_iter(self):       
        return self.html_xpath(parse_hidden_elements(self.tree), '//h:table[@class ="uiGrid eventsGrid"]')
        
    def process_event_node(self, item, event_node):
        
        rel_url = self.html_xpath(event_node, './/h:a[1]/@href')[0]
        abs_url = urljoin(item['page_url'], rel_url)
        item['page_url'] = abs_url

class FacebookEventParser(SemanticsMatcher):
        
    def event_node_iter(self):
        #print(etree.tostring(self.tree))
        return [self.tree]
        
    def process_event_node(self, item, event_node):
        parsed_hidden_elem_title = parse_hidden_elements(event_node)
        parsed_hidden_elem_details = parse_hidden_elements(event_node)
        
        item['title'] = self.html_xpath_text(parsed_hidden_elem_title, './/h:div[@itemprop="summary"]')
        item['description'] =  self.collect_texts(parsed_hidden_elem_details, './/h:span[@itemprop="description"]')
        
        period_string = self.html_xpath(parsed_hidden_elem_details, './/h:div[@itemprop = "startDate"]/@content')[0]
        item['start_datetime'] = datetime.strptime(period_string[:19], '%Y-%m-%dT%H:%M:%S') + timedelta(hours=9)
        #endtime = (datetime.strptime(period_string[20:], '%H:%M') + timedelta(hours=9)).time()
        #item['end_datetime'] = self.calculate_enddatetime(item['start_datetime'], endtime)
        item['end_datetime'] = None


from zope.interface import classProvides, implements
from collective.transmogrifier.interfaces import ISectionBlueprint
from collective.transmogrifier.interfaces import ISection
from transmogrify.pathsorter.treeserializer import TreeSerializer

import logging
from lxml import etree
import os

class EventImportDefinitionSection(object):
    classProvides(ISectionBlueprint)
    implements(ISection)

    def __init__(self, transmogrifier, name, options, previous):
        self.previous = TreeSerializer(transmogrifier, name, options, previous)
        self.context = transmogrifier.context
        self.logger = logging.getLogger(name)

        self.directory = options.get('directory','')

    def __iter__(self):
        for item in self.previous:
            yield item
            
            
        for root, subFolders, files in os.walk(self.directory):
            
            for filename in files:
                if filename.endswith('.xml'):
                    definition_filepath = os.path.join(root, filename)
                    
                    with open(definition_filepath) as definition_file:
                        tree = etree.parse(definition_file)
                        
                        enabled = tree.xpath('/event-import/@enabled')[0]
                        
                        if enabled != 'true':
                            continue
                        
                        venue_name = tree.getroot().get('venue-name')
                        venue_website = tree.getroot().get('venue-website')
                        identify_venue_by = tree.getroot().get('identify-venue-by')
                        
                        item = {}                 
                        directory = os.path.dirname(definition_filepath)
                        item['eventimport_definition_path'] = definition_filepath
                        item['eventimport_definition_directory'] = directory
                        item['stylesheet_baseurl'] = 'file://' + directory + '/'
                        item['venue_website'] = venue_website
                        item['crawl_pages'] = tree.xpath('//crawl-page')
                        
                        if venue_name:
                            item['venue_name'] = venue_name
                            
                        if identify_venue_by:
                            item['identify_venue_by'] = identify_venue_by
                        
                        yield item


import unittest2 as unittest

from Products.CMFCore.utils import getToolByName

from wasgehtengine.import.testing import \
    WASGEHTENGINE_IMPORT_INTEGRATION_TESTING


class TestExample(unittest.TestCase):

    layer = WASGEHTENGINE_IMPORT_INTEGRATION_TESTING

    def setUp(self):
        self.app = self.layer['app']
        self.portal = self.layer['portal']
        self.qi_tool = getToolByName(self.portal, 'portal_quickinstaller')

    def test_product_is_installed(self):
        """ Validate that our products GS profile has been run and the product
            installed
        """
        pid = 'wasgehtengine.import'
        installed = [p['id'] for p in self.qi_tool.listInstalledProducts()]
        self.assertTrue(pid in installed,
                        'package appears not to have been installed')



# -*- coding: utf-8 -*-
from zope.interface import classProvides, implements
from collective.transmogrifier.interfaces import ISectionBlueprint
from collective.transmogrifier.interfaces import ISection
from transmogrify.pathsorter.treeserializer import TreeSerializer

import logging
import sys

from importlib import import_module
facebook = import_module('wasgehtengine.import.event_import_definitions.facebook')

class PyTransformSection(object):
    classProvides(ISectionBlueprint)
    implements(ISection)

    def __init__(self, transmogrifier, name, options, previous):
        self.previous = TreeSerializer(transmogrifier, name, options, previous)
        self.context = transmogrifier.context
        
        self.logger = logging.getLogger(name)

    def __iter__(self):
        for item in self.previous:
                        
            if 'https://www.facebook.com' in item['page_url']:
                self.parser = facebook.FacebookEventParser
            elif not 'script' in item:
                yield item
                continue
            else:
                # TODO: Is there a better way to do this?
                sys.path.insert(0, item['eventimport_definition_directory'])
                self.parser = getattr(__import__(item['script']), 'Parser')
            
            for parsed_item in self.parser(item, item['page']):                    
                yield parsed_item


from zope.interface import classProvides, implements
from zope import component
from collective.transmogrifier.interfaces import ISectionBlueprint
from collective.transmogrifier.interfaces import ISection
from transmogrify.pathsorter.treeserializer import TreeSerializer
from Products.CMFCore.utils import getToolByName
from z3c.relationfield.relation import create_relation
from urlparse import urlparse

import logging

class VenueResolverSection(object):
    classProvides(ISectionBlueprint)
    implements(ISection)

    def __init__(self, transmogrifier, name, options, previous):
        self.previous = TreeSerializer(transmogrifier, name, options, previous)
        self.context = transmogrifier.context
        
        self.catalog = getToolByName(self.context, 'portal_catalog')

        self.logger = logging.getLogger(name)

    def __iter__(self):
        for item in self.previous:
            
            url = urlparse(item['venue_website'])
            
            if 'identify_venue_by' in item and item['identify_venue_by'] == 'name' and 'venue_name' in item:
                self.logger.debug('Searching venue with Title "' + item['venue_name'] + '"...')
                results = self.catalog.searchResults({'portal_type': 'wasgehtengine.Venue', 'Title': item['venue_name']})
                
                for brain in results:
                    if brain.getObject().title == item['venue_name']:
                        item['venue'] = create_relation(brain.getPath())
                
                if not 'venue' in item:
                    self.logger.warning('Did not find a venue with title "' + item['venue_name'] + '" in database. Dropping the events.')
                    continue
            
            else:
                self.logger.debug('Searching venue with website "' + url.netloc + '"...')
            
                results = self.catalog.searchResults({'portal_type': 'wasgehtengine.Venue', 'website': url.netloc})
            
                if len(results) == 0:
                    self.logger.warning('Did not find a venue with website ' + url.netloc + ' in database. Dropping the events.')
                    continue
                
                elif len(results) == 1:
                    item['venue'] = create_relation(results[0].getPath())
                
                elif len(results) > 1 and not 'identify_venue_by' in item:
                    self.logger.warning('Found more than one venue with website ' + item['venue_website'] + ' in database:')
                    for brain in results:
                        self.logger.warning(brain.getPath())
                    
                    self.logger.warning('Using the first one.')
                        
                    item['venue'] = create_relation(results[0].getPath())
                
                elif 'identify_venue_by' in item and item['identify_venue_by'] == 'fullurl':
                        
                    for brain in results:
                        if brain.getObject().website == url.geturl():
                            item['venue'] = create_relation(brain.getPath())
                            
                    if not 'venue' in item:
                        self.logger.warning('Did not find a venue with fullurl ' + url.geturl() + ' in database. Dropping the events.')
                        continue
            
            yield item


from zope.interface import classProvides, implements
from collective.transmogrifier.interfaces import ISectionBlueprint
from collective.transmogrifier.interfaces import ISection
from transmogrify.pathsorter.treeserializer import TreeSerializer

import logging
from lxml.html import html5parser, tostring
import chardet
import urllib2

class HtmlParserSection(object):
    classProvides(ISectionBlueprint)
    implements(ISection)

    def __init__(self, transmogrifier, name, options, previous):
        self.previous = TreeSerializer(transmogrifier, name, options, previous)
        self.context = transmogrifier.context

        self.logger = logging.getLogger(name)

    def __iter__(self):
        for item in self.previous:
            if item['format'] == 'html' and not 'page' in item:
                content = urllib2.urlopen(item['page_url']).read()
                
                encoding = False
                
                if 'force_encoding' in item:
                    encoding = item['force_encoding']
                    self.logger.debug('forced encoding '+encoding)
                elif 'guess_encoding' in item:
                    encoding = chardet.detect(content)['encoding']
                    self.logger.debug('detected encoding ' + encoding)
                    
                if encoding and encoding != 'utf-8':
                    self.logger.debug('not unicode, converting...')
                    content = content.decode(encoding, 'replace').encode('utf-8')
                
                item['page'] = html5parser.fromstring(content)
                #item['page_string'] = tostring(item['page']) 
                            
            yield item


# -*- coding: utf-8 -*-
from lxml import etree
import re
from datetime import datetime
from datetime import date
from datetime import time
from datetime import timedelta

# TODO improve name
class SemanticsMatcher(object):
    ns = {'h': 'http://www.w3.org/1999/xhtml'}
    
    def __init__(self, base_item, tree):
        self.base_item = base_item
        self.tree = tree
    
    def html_xpath(self, node, expr):
        return node.xpath(expr, namespaces=self.ns)
    
    def html_xpath_text(self, node, expr):
        nodes = node.xpath(expr, namespaces=self.ns)
        if nodes:
            return nodes[0].text
        else:
            return ""
    
    def html_find(self, node, expr):
        return node.find(expr, namespaces=self.ns)
    
    def html_find_text(self, node, expr):
        return unicode(self.html_find(node, expr).text)
    
    def collect_texts(self, node, expr):
        return ''.join(self.html_xpath(node, expr + '/descendant-or-self::text()'))
    
    def calculate_enddatetime(self, startdatetime, endtime):
        at_same_day = datetime.combine(startdatetime.date(), endtime)
        
        if at_same_day > startdatetime:
            return at_same_day
        else:
            return datetime.combine(startdatetime.date() + timedelta(1), endtime)
    
    # TODO Are these substring functions not part of standard python libraries???
    def substring_before(self, s, substring):
        try:
            return s[:s.index(substring)]
        except ValueError:
            return ""
        
    def substring_after(self, s, substring):
        try:
            start = s.index( substring ) + len( substring )
            return s[start:]
        except ValueError:
            return ""
        
    def substring_between(self, s, first, last):
        return self.substring_before(self.substring_after(s, first), last)
    
    def next_possible_date(self, month, day):
        this_year = datetime.today().replace(month=month).replace(day=day)
        
        if this_year > datetime.today():
            return this_year
        
        return (datetime.today() + timedelta(365)).replace(month=month).replace(day=day)
            
    # abstract method
    def event_node_iter(self):
        pass
    
    # abstract method
    def process_event_node(self, item, event_node):
        pass
    
    def __iter__(self):
        for event_node in self.event_node_iter():
            item = self.base_item.copy()
            self.process_event_node(item, event_node)
            yield item


from zope.interface import classProvides, implements
from collective.transmogrifier.interfaces import ISectionBlueprint
from collective.transmogrifier.interfaces import ISection
from transmogrify.pathsorter.treeserializer import TreeSerializer
from datetime import datetime
import logging
from lxml import etree

def parse_datetime(date_element, time_element):
        if date_element is None:
            return None
        
        if time_element is None:
            return datetime.strptime(date_element.text, '%Y-%m-%d')
        
        return datetime.strptime(date_element.text + 'T' + time_element.text, '%Y-%m-%dT%H:%M:%S')

class EventListSection(object):
    classProvides(ISectionBlueprint)
    implements(ISection)

    def __init__(self, transmogrifier, name, options, previous):
        self.previous = TreeSerializer(transmogrifier, name, options, previous)
        self.context = transmogrifier.context

        self.logger = logging.getLogger(name)

    def __iter__(self):
        for item in self.previous:
            
            if not 'eventlist' in item:
                yield item
                continue
            
            tree = item['eventlist']
            
            for event in tree.xpath('//event'):
                item = item.copy()
                
                #item['date'] = event.xpath('occurrence[1]/start-date')
                
                item['title'] = event.find('name').text.strip()
                item['description'] = event.find('description').text.strip()

                item['start_datetime'] = parse_datetime(event.find('occurrence/start-date'), event.find('occurrence/start-time'))
                item['end_datetime'] = parse_datetime(event.find('occurrence/end-date'), event.find('occurrence/end-time'))
                                                    
                yield item


from zope.interface import classProvides, implements
from collective.transmogrifier.interfaces import ISectionBlueprint
from collective.transmogrifier.interfaces import ISection
from transmogrify.pathsorter.treeserializer import TreeSerializer
from zope.component import queryUtility
from plone.i18n.normalizer.interfaces import IIDNormalizer
from wasgehtengine.contenttypes.osmelement import OsmElement
from wasgehtengine.contenttypes.geoposition import GeoPosition

import logging
import urllib
import urlparse
from lxml import etree

class OsmSection(object):
    classProvides(ISectionBlueprint)
    implements(ISection)

    def __init__(self, transmogrifier, name, options, previous):
        self.previous = TreeSerializer(transmogrifier, name, options, previous)
        self.context = transmogrifier.context
        self.normalizer = queryUtility(IIDNormalizer)

        self.type = 'wasgehtengine.Venue'
        self.logger = logging.getLogger(name)
        self.basepath = 'venues/'
        
    def process_tags(self, item, elem):
        for tag in elem.xpath('tag'):
            
            # If node has a name, use it for path instead of ID
            if tag.get('k') == 'name':
                item['_path'] = self.basepath + self.normalizer.normalize(tag.get('v'))
                item['title'] = tag.get('v')
                
            elif tag.get('k') == 'contact:website' or tag.get('k') == 'website':
                # need to convert internationalized domain names to pure ascii hostnames
                website = tag.get('v').encode('idna')
                
                url = urlparse.urlparse(website)
                        
                if not url.scheme:
                    url = urlparse.urlparse('http://' + website)
                            
                item['website'] = url.geturl()
            elif tag.get('k').startswith('addr:'):
                item['postalAddress'][tag.get('k')[5:]] = tag.get('v')
            elif tag.get('k') == 'contact:phone':
                item['phoneNumber'] = tag.get('v')             
            else:
                item['osmReference'].osmElementTags[tag.get('k')] = tag.get('v')
                
    def area_size(p):
        return 0.5 * abs(sum(x0*y1 - x1*y0 for ((x0, y0), (x1, y1)) in segments(p)))
    
    def segments(p):
        return zip(p, p[1:] + [p[0]])
                
    def calculate_area_centroid(self, item, elem):
        # TODO implement
        #nodes = elem.xpath("../node[@id = current()/nd/@ref]")
        #print(nodes)
        
        return GeoPosition({'latitude': '50.7268111', 'longitude': '7.1052570'})
        

    def __iter__(self):
        for item in self.previous:

            f = urllib.urlopen('http://www.overpass-api.de/api/xapi?' + item['query_params'])
            
            tree = etree.parse(f)
            
            for elem in tree.xpath("/osm/*[tag/@k = 'name']"):
                item = {}
                item['_type'] = self.type
                item['creators'] = ['osm-venue-importer']
                item['osm-id'] = elem.get('id')
                item['transitions'] = ["publish"]
                item['postalAddress'] = {}
                
                osmElementType = 'Node' if elem.tag == 'node' else 'Way'
                item['osmReference'] = OsmElement({'osmElementId': item['osm-id'], 'osmElementType': osmElementType, 'osmElementTags': {}})
                
                if elem.get('lat'):
                    item['geographicPosition'] = GeoPosition({'latitude': elem.get('lat'), 'longitude': elem.get('lon')})
                else:
                    item['geographicPosition'] = self.calculate_area_centroid(item, elem)
                
                self.process_tags(item, elem)
                self.logger.info('Importing venue "'+ item['title'] + '"')
                
                yield item
                item = None


from zope.interface import classProvides, implements
from collective.transmogrifier.interfaces import ISectionBlueprint
from collective.transmogrifier.interfaces import ISection
from transmogrify.pathsorter.treeserializer import TreeSerializer

import logging
from lxml import etree

class XslTransformSection(object):
    classProvides(ISectionBlueprint)
    implements(ISection)

    def __init__(self, transmogrifier, name, options, previous):
        self.previous = TreeSerializer(transmogrifier, name, options, previous)
        self.context = transmogrifier.context

        self.logger = logging.getLogger(name)

    def __iter__(self):
        for item in self.previous:
            
            if not 'stylesheet' in item:
                yield item
                continue
            
            try:
                stylesheet = etree.parse(item['stylesheet'], base_url=item['stylesheet_baseurl'])
            
                transform = etree.XSLT(stylesheet)
            except etree.XSLTParseError as e:
                print e
                continue
            except etree.XMLSyntaxError as e:
                print e
                continue
            
            if 'eventlinks_stylesheet' in item:
#                eventlinks_stylesheet = etree.parse(item['eventlinks_stylesheet'], base_url=item['stylesheet_baseurl'])
#                try:
#                    eventlinks_transform = etree.XSLT(eventlinks_stylesheet)
#                except etree.XSLTParseError as e:
#                    print e
#                except etree.XMLSyntaxError as e:
#                    print e
#                    
#                result = eventlinks_transform(item['page'])
                pass
            else:
                item['eventlist'] = transform(item['page'])
            
            yield item


from  wasgehtengine.import.testing import WASGEHTENGINE_IMPORT_FUNCTIONAL_TESTING
from plone.testing import layered
import robotsuite
import unittest


def test_suite():
    suite = unittest.TestSuite()
    suite.addTests([
        layered(robotsuite.RobotTestSuite("robot_test.txt"),
                layer=WASGEHTENGINE_IMPORT_FUNCTIONAL_TESTING)
    ])
    return suite


from zope.interface import classProvides, implements
from collective.transmogrifier.interfaces import ISectionBlueprint
from collective.transmogrifier.interfaces import ISection
from transmogrify.pathsorter.treeserializer import TreeSerializer

from datetime import datetime as dt
from datetime import timedelta

import logging
import urllib

class UrlAssemblerSection(object):
    classProvides(ISectionBlueprint)
    implements(ISection)

    def __init__(self, transmogrifier, name, options, previous):
        self.previous = TreeSerializer(transmogrifier, name, options, previous)
        self.context = transmogrifier.context

        self.logger = logging.getLogger(name)
        
        self.now = dt.now()
        
    def replace_datetime_pattern(self, pattern, datetime):
        return datetime.strftime(pattern)
        
    def generate_parameters(self, parameters, datetime):
        params = {}
        
        for key, pattern in parameters.items():
            params[key] = self.replace_datetime_pattern(pattern, datetime)           
        
        return urllib.urlencode(params)

    def __iter__(self):
        for item in self.previous:
                        
            if item['parameters']:
                page_urls = [item['base_url'] + ('&' if '?' in item['base_url'] else '?') + self.generate_parameters(item['parameters'], self.now),
                             item['base_url'] + ('&' if '?' in item['base_url'] else '?') + self.generate_parameters(item['parameters'], self.now + timedelta(30))]
            else:
                page_urls = [item['base_url']]
            
            for page_url in page_urls:
                item = item.copy()
                item['page_url'] = page_url
                yield item


from zope.interface import classProvides, implements
from collective.transmogrifier.interfaces import ISectionBlueprint
from collective.transmogrifier.interfaces import ISection
from transmogrify.pathsorter.treeserializer import TreeSerializer
from plone.i18n.normalizer.interfaces import IIDNormalizer
from zope.component import queryUtility
from wasgehtengine.contenttypes.period import Period

import logging

class EventValidatorSection(object):
    classProvides(ISectionBlueprint)
    implements(ISection)

    def __init__(self, transmogrifier, name, options, previous):
        self.previous = TreeSerializer(transmogrifier, name, options, previous)
        self.context = transmogrifier.context
        self.normalizer = queryUtility(IIDNormalizer)

        self.logger = logging.getLogger(name)
        self.basepath = 'events/'
        self.type = 'wasgehtengine.Event'

    def __iter__(self):
        for item in self.previous:
            if not 'title' in item or item['title'] is None:
                self.logger.warning('Event has no title, dropping it.')
                continue
            
            if not 'start_datetime' in item or item['start_datetime'] is None:
                self.logger.warning('Event with title "'+item['title'] + '" has no startdate, dropping it.')
                continue
            
            if not 'venue' in item or item['venue'] is None:
                self.logger.warning('Event with title "'+item['title'] + '" has no venue, dropping it.')
                continue
            
            item['_path'] = self.basepath + self.normalizer.normalize(item['title']) + '-' + self.normalizer.normalize(item['start_datetime'].date().isoformat())
            item['_type'] = self.type
            item['creators'] = ['event-importer']
            item['transitions'] = ["publish"]
            item['website'] = item['page_url']
            
            period = Period()
            period.start = item['start_datetime']
            if 'end_datetime' in item:
                period.end = item['end_datetime']
            item['period'] = period
            
            self.logger.info(item['venue'].to_path + ': Importing event "' + item['title'] + '"')
            
            yield item


from zope.interface import classProvides, implements
from collective.transmogrifier.interfaces import ISectionBlueprint
from collective.transmogrifier.interfaces import ISection
from transmogrify.pathsorter.treeserializer import TreeSerializer

import logging
from lxml import etree
import os

class OsmImportDefinitionSection(object):
    classProvides(ISectionBlueprint)
    implements(ISection)

    def __init__(self, transmogrifier, name, options, previous):
        self.previous = TreeSerializer(transmogrifier, name, options, previous)
        self.context = transmogrifier.context
        self.logger = logging.getLogger(name)

        self.file = options.get('file','')

    def __iter__(self):
        for item in self.previous:
            yield item
            
        with open(self.file) as definition_file:
            tree = etree.parse(definition_file)
                        
            queries = tree.getroot().findall('query')
            
            for query in queries:
                
                for type in query.get('elements').split(','):
                    
                    query_params = type
                    
                    for predicate in query.findall('predicate'):
                        query_params += ('[' + predicate.text + ']')
                    
                    item = { 'query_params': query_params }
                    print(query_params)
                                           
                    yield item


from zope.interface import classProvides, implements
from collective.transmogrifier.interfaces import ISectionBlueprint
from collective.transmogrifier.interfaces import ISection
from transmogrify.pathsorter.treeserializer import TreeSerializer

import logging
import requests
import urllib2
from lxml import etree

class XmlParserSection(object):
    classProvides(ISectionBlueprint)
    implements(ISection)

    def __init__(self, transmogrifier, name, options, previous):
        self.previous = TreeSerializer(transmogrifier, name, options, previous)
        self.context = transmogrifier.context

        self.logger = logging.getLogger(name)

    def __iter__(self):
        for item in self.previous:
            if item['format'] == 'xml' and not 'page' in item:
                res = requests.get(item['page_url'])
                    
                # works because the 38 character encoding declaration is sliced off
                # would otherwise throw 'Unicode strings with encoding declaration are not supported.'
                # TODO fix properly
                item['page'] = etree.fromstring(res.text[38:])
                #item['page_string'] = res.content 
                            
            yield item


from zope.interface import classProvides, implements
from collective.transmogrifier.interfaces import ISectionBlueprint
from collective.transmogrifier.interfaces import ISection
from transmogrify.pathsorter.treeserializer import TreeSerializer

import logging
import os

class CrawlPagesExpanderSection(object):
    classProvides(ISectionBlueprint)
    implements(ISection)

    def __init__(self, transmogrifier, name, options, previous):
        self.previous = TreeSerializer(transmogrifier, name, options, previous)
        self.context = transmogrifier.context
        self.logger = logging.getLogger(name)

    def __iter__(self):
        for item in self.previous:
            
            for crawl_page in item['crawl_pages']:
                crawl_page_item = item.copy()
                            
                if crawl_page.get('stylesheet'):
                    crawl_page_item['stylesheet'] = os.path.join(item['eventimport_definition_directory'], crawl_page.get('stylesheet'))
                                
                if crawl_page.get('script'):
                    crawl_page_item['script'] = crawl_page.get('script')
                    
                if crawl_page.get('eventlinks-script'):
                    crawl_page_item['eventlinks-script'] = crawl_page.get('eventlinks-script')
                                
                if crawl_page.get('eventlinks-stylesheet'):
                    crawl_page_item['eventlinks_stylesheet'] = os.path.join(item['eventimport_definition_directory'], crawl_page.get('eventlinks-stylesheet'))
                    
                if crawl_page.get('force-encoding'):
                    crawl_page_item['force_encoding'] = crawl_page.get('force-encoding')
                    
                if crawl_page.get('guess-encoding'):
                    crawl_page_item['guess_encoding'] = crawl_page.get('guess-encoding')
                                
                crawl_page_item['base_url'] = crawl_page.get('url')
                crawl_page_item['format'] =  crawl_page.get('format')
                            
                crawl_page_item['parameters'] = {}
                
                for parameter in crawl_page.xpath('date-parameter'):
                    crawl_page_item['parameters'][parameter.get('name')] = parameter.get('pattern')
                            
                yield crawl_page_item



from five import grok
from plone.app.layout.navigation.interfaces import INavigationRoot
from collective.transmogrifier.transmogrifier import Transmogrifier
from zope.site.hooks import getSite
from plone.memoize import ram
import logging

class ImportForm(grok.View):
	""" Form for Import
	"""

	grok.context(INavigationRoot)
	grok.name('import')
	grok.require('wasgehtengine.Import')
	
	logger = logging.getLogger('importform')

	def update(self):
		pass

	def __call__(self):

		form = self.request.form
	
		importVenuesButton = form.get('form.button.import-venues') is not None
		importEventsButton = form.get('form.button.import-events') is not None
		
		venue_import_config = form.get('osm-import-configfile')
		event_import_dir = form.get('event-import-definitions-dir')		

		if(self.request.get('REQUEST_METHOD', 'GET').upper() == 'POST'):
			transmogrifier = Transmogrifier(getSite())

			if importVenuesButton:
				self.logger.info("Importing venues...")
				transmogrifier("osm-venue-import",
							osmimportdefinitionssource=dict(file=venue_import_config))

			elif importEventsButton:
				self.logger.info("Importing events...")
				transmogrifier("event-import", eventimportdefinitionssource=dict(directory=event_import_dir))
				
			# clear all cached values 
			ram.global_cache.invalidateAll()

		return super(ImportForm, self).__call__()



# -*- coding: utf-8 -*-
from setuptools import setup, find_packages
import os

version = '1.0.1'

long_description = (
    open('README.txt').read()
    + '\n' +
    'Contributors\n'
    '============\n'
    + '\n' +
    open('CONTRIBUTORS.txt').read()
    + '\n' +
    open('CHANGES.txt').read()
    + '\n')

setup(name='wasgehtengine.import',
      version=version,
      description="Import content into wasgehtengine",
      long_description=long_description,
      # Get more strings from
      # http://pypi.python.org/pypi?%3Aaction=list_classifiers
      classifiers=[
        "Environment :: Web Environment",
        "Framework :: Plone",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2.7",
        "Topic :: Software Development :: Libraries :: Python Modules",
        ],
      keywords='',
      author='Fabian Köster',
      author_email='koesterreich@fastmail.fm',
      url='https://gitorious.org/wasgehtengine',
      license='agpl',
      packages=find_packages('src'),
      package_dir={'': 'src'},
      namespace_packages=['wasgehtengine', ],
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          'setuptools',
          'wasgehtengine.contenttypes',
          'collective.transmogrifier',
          'transmogrify.dexterity',
          'transmogrify.xmlsource',
          'transmogrify.pathsorter',
          'plone.app.transmogrifier',
          'html5lib',
          'requests',
          'chardet',
          # -*- Extra requirements: -*-
      ],
      extras_require={'test': ['plone.app.testing']},
      entry_points="""
      # -*- Entry points: -*-
      [z3c.autoinclude.plugin]
      target = plone
      """,
      setup_requires=["PasteScript"],
      paster_plugins=["templer.localcommands"],
      )
